@@ -293,6 +293,7 @@ static int wrap_aarch64_hash_init(gnutls_digest_algorithm_t algo, void **_ctx)
 	ctx->algo = algo;
 
 	if ((ret = _ctx_init(algo, ctx)) < 0) {
+		gnutls_free(ctx);
 		gnutls_assert();
 		return ret;
 	}
@@ -326,6 +327,11 @@ static int wrap_aarch64_hash_output(void *src_ctx, void *digest,
 	struct aarch64_hash_ctx *ctx;
 	ctx = src_ctx;
 
+	if (digest == NULL) {
+		ctx->init(ctx->ctx_ptr);
+		return 0;
+	}
+
 	if (digestsize < ctx->length)
 		return gnutls_assert_val(GNUTLS_E_SHORT_MEMORY_BUFFER);
 
