@@ -16,7 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>
  *
  */
 
@@ -31,11 +31,11 @@
 
 #include <gnutls/crypto.h>
 #include "errors.h"
-#include <aes-x86.h>
-#include <x86-common.h>
+#include "aes-x86.h"
+#include "x86-common.h"
 #include <byteswap.h>
 #include <nettle/gcm.h>
-#include <aes-padlock.h>
+#include "aes-padlock.h"
 
 #define GCM_BLOCK_SIZE 16
 
@@ -43,13 +43,15 @@
  * Actually padlock doesn't include GCM mode. We just use
  * the ECB part of padlock and nettle for everything else.
  */
-struct gcm_padlock_aes_ctx GCM_CTX(struct padlock_ctx);
+struct gcm_padlock_aes_ctx {
+	struct GCM_CTX(struct padlock_ctx) inner;
+	size_t rekey_counter;
+};
 
-static void padlock_aes_encrypt(const void *_ctx,
-				size_t length, uint8_t * dst,
-				const uint8_t * src)
+static void padlock_aes_encrypt(const void *_ctx, size_t length, uint8_t *dst,
+				const uint8_t *src)
 {
-	struct padlock_ctx *ctx = (void*)_ctx;
+	struct padlock_ctx *ctx = (void *)_ctx;
 	struct padlock_cipher_data *pce;
 
 	pce = ALIGN16(&ctx->expanded_key);
@@ -59,7 +61,7 @@ static void padlock_aes_encrypt(const void *_ctx,
 }
 
 static void padlock_aes128_set_encrypt_key(struct padlock_ctx *_ctx,
-					const uint8_t * key)
+					   const uint8_t *key)
 {
 	struct padlock_ctx *ctx = _ctx;
 	ctx->enc = 1;
@@ -68,7 +70,7 @@ static void padlock_aes128_set_encrypt_key(struct padlock_ctx *_ctx,
 }
 
 static void padlock_aes256_set_encrypt_key(struct padlock_ctx *_ctx,
-					const uint8_t * key)
+					   const uint8_t *key)
 {
 	struct padlock_ctx *ctx = _ctx;
 	ctx->enc = 1;
@@ -78,15 +80,14 @@ static void padlock_aes256_set_encrypt_key(struct padlock_ctx *_ctx,
 
 static void aes_gcm_deinit(void *_ctx)
 {
-	struct padlock_ctx *ctx = _ctx;
+	struct gcm_padlock_aes_ctx *ctx = _ctx;
 
-	zeroize_temp_key(ctx, sizeof(*ctx));
+	zeroize_key(ctx, sizeof(*ctx));
 	gnutls_free(ctx);
 }
 
-static int
-aes_gcm_cipher_init(gnutls_cipher_algorithm_t algorithm, void **_ctx,
-		    int enc)
+static int aes_gcm_cipher_init(gnutls_cipher_algorithm_t algorithm, void **_ctx,
+			       int enc)
 {
 	/* we use key size to distinguish */
 	if (algorithm != GNUTLS_CIPHER_AES_128_GCM &&
@@ -102,19 +103,20 @@ aes_gcm_cipher_init(gnutls_cipher_algorithm_t algorithm, void **_ctx,
 	return 0;
 }
 
-static int
-aes_gcm_cipher_setkey(void *_ctx, const void *key, size_t keysize)
+static int aes_gcm_cipher_setkey(void *_ctx, const void *key, size_t keysize)
 {
 	struct gcm_padlock_aes_ctx *ctx = _ctx;
 
 	if (keysize == 16) {
-		GCM_SET_KEY(ctx, padlock_aes128_set_encrypt_key, padlock_aes_encrypt,
-			    key);
+		GCM_SET_KEY(&ctx->inner, padlock_aes128_set_encrypt_key,
+			    padlock_aes_encrypt, key);
 	} else if (keysize == 32) {
-		GCM_SET_KEY(ctx, padlock_aes256_set_encrypt_key, padlock_aes_encrypt,
-			    key);
-	} else abort();
+		GCM_SET_KEY(&ctx->inner, padlock_aes256_set_encrypt_key,
+			    padlock_aes_encrypt, key);
+	} else
+		return GNUTLS_E_INVALID_REQUEST;
 
+	ctx->rekey_counter = 0;
 	return 0;
 }
 
@@ -125,29 +127,40 @@ static int aes_gcm_setiv(void *_ctx, const void *iv, size_t iv_size)
 	if (iv_size != GCM_BLOCK_SIZE - 4)
 		return gnutls_assert_val(GNUTLS_E_INVALID_REQUEST);
 
-	GCM_SET_IV(ctx, iv_size, iv);
+	GCM_SET_IV(&ctx->inner, iv_size, iv);
+
+	ctx->rekey_counter = 0;
+	return 0;
+}
+
+static int aes_gcm_encrypt(void *_ctx, const void *src, size_t src_size,
+			   void *dst, size_t length)
+{
+	struct gcm_padlock_aes_ctx *ctx = _ctx;
+	int ret;
+
+	if (unlikely(length < src_size))
+		return gnutls_assert_val(GNUTLS_E_SHORT_MEMORY_BUFFER);
+
+	ret = record_aes_gcm_encrypt_size(&ctx->rekey_counter, src_size);
+	if (ret < 0) {
+		return gnutls_assert_val(ret);
+	}
+
+	GCM_ENCRYPT(&ctx->inner, padlock_aes_encrypt, src_size, dst, src);
 
 	return 0;
 }
 
-static int
-aes_gcm_encrypt(void *_ctx, const void *src, size_t src_size,
-		void *dst, size_t length)
+static int aes_gcm_decrypt(void *_ctx, const void *src, size_t src_size,
+			   void *dst, size_t dst_size)
 {
 	struct gcm_padlock_aes_ctx *ctx = _ctx;
 
-	GCM_ENCRYPT(ctx, padlock_aes_encrypt, src_size, dst, src);
+	if (unlikely(dst_size < src_size))
+		return gnutls_assert_val(GNUTLS_E_SHORT_MEMORY_BUFFER);
 
-	return 0;
-}
-
-static int
-aes_gcm_decrypt(void *_ctx, const void *src, size_t src_size,
-		void *dst, size_t dst_size)
-{
-	struct gcm_padlock_aes_ctx *ctx = _ctx;
-
-	GCM_DECRYPT(ctx, padlock_aes_encrypt, src_size, dst, src);
+	GCM_DECRYPT(&ctx->inner, padlock_aes_encrypt, src_size, dst, src);
 	return 0;
 }
 
@@ -155,7 +168,7 @@ static int aes_gcm_auth(void *_ctx, const void *src, size_t src_size)
 {
 	struct gcm_padlock_aes_ctx *ctx = _ctx;
 
-	GCM_UPDATE(ctx, src_size, src);
+	GCM_UPDATE(&ctx->inner, src_size, src);
 
 	return 0;
 }
@@ -164,7 +177,7 @@ static void aes_gcm_tag(void *_ctx, void *tag, size_t tagsize)
 {
 	struct gcm_padlock_aes_ctx *ctx = _ctx;
 
-	GCM_DIGEST(ctx, padlock_aes_encrypt, tagsize, tag);
+	GCM_DIGEST(&ctx->inner, padlock_aes_encrypt, tagsize, tag);
 }
 
 #include "aes-gcm-aead.h"
