@@ -24,21 +24,21 @@
 #include "gnutls_int.h"
 #include <gnutls/crypto.h>
 #include "errors.h"
-#include <aes-x86.h>
+#include "aes-x86.h"
 #include <nettle/sha.h>
 #include <nettle/macros.h>
 #include <nettle/nettle-meta.h>
-#include <sha-x86.h>
-#include <x86-common.h>
+#include "sha-x86.h"
+#include "x86-common.h"
 
 void sha1_block_data_order(void *c, const void *p, size_t len);
 void sha256_block_data_order(void *c, const void *p, size_t len);
 void sha512_block_data_order(void *c, const void *p, size_t len);
 
-typedef void (*update_func) (void *, size_t, const uint8_t *);
-typedef void (*digest_func) (void *, size_t, uint8_t *);
-typedef void (*set_key_func) (void *, size_t, const uint8_t *);
-typedef void (*init_func) (void *);
+typedef void (*update_func)(void *, size_t, const uint8_t *);
+typedef void (*digest_func)(void *, size_t, uint8_t *);
+typedef void (*set_key_func)(void *, size_t, const uint8_t *);
+typedef void (*init_func)(void *);
 
 struct x86_hash_ctx {
 	union {
@@ -56,8 +56,7 @@ struct x86_hash_ctx {
 	init_func init;
 };
 
-static int
-wrap_x86_hash_update(void *_ctx, const void *text, size_t textsize)
+static int wrap_x86_hash_update(void *_ctx, const void *text, size_t textsize)
 {
 	struct x86_hash_ctx *ctx = _ctx;
 
@@ -71,8 +70,7 @@ static void wrap_x86_hash_deinit(void *hd)
 	gnutls_free(hd);
 }
 
-void x86_sha1_update(struct sha1_ctx *ctx, size_t length,
-		     const uint8_t * data)
+void x86_sha1_update(struct sha1_ctx *ctx, size_t length, const uint8_t *data)
 {
 	struct {
 		uint32_t h0, h1, h2, h3, h4;
@@ -105,12 +103,11 @@ void x86_sha1_update(struct sha1_ctx *ctx, size_t length,
 	length -= res;
 
 	if (length > 0) {
-
 		t2 = length / SHA1_DATA_SIZE;
 
 		sha1_block_data_order(&octx, data, t2);
 
-		for (i=0;i<t2;i++)
+		for (i = 0; i < t2; i++)
 			ctx->count++;
 		data += length;
 	}
@@ -127,11 +124,10 @@ void x86_sha1_update(struct sha1_ctx *ctx, size_t length,
 	if (res > 0) {
 		sha1_update(ctx, res, data);
 	}
-
 }
 
 void x86_sha256_update(struct sha256_ctx *ctx, size_t length,
-		     const uint8_t * data)
+		       const uint8_t *data)
 {
 	struct {
 		uint32_t h[8];
@@ -162,8 +158,8 @@ void x86_sha256_update(struct sha256_ctx *ctx, size_t length,
 	if (length > 0) {
 		t2 = length / SHA1_DATA_SIZE;
 		sha256_block_data_order(&octx, data, t2);
-		
-		for (i=0;i<t2;i++)
+
+		for (i = 0; i < t2; i++)
 			ctx->count++;
 		data += length;
 	}
@@ -179,14 +175,14 @@ void x86_sha256_update(struct sha256_ctx *ctx, size_t length,
 }
 
 void x86_sha512_update(struct sha512_ctx *ctx, size_t length,
-		     const uint8_t * data)
+		       const uint8_t *data)
 {
 	struct {
 		uint64_t h[8];
 		uint64_t Nl, Nh;
 		union {
 			uint64_t d[16];
-			uint8_t p[16*8];
+			uint8_t p[16 * 8];
 		} u;
 		unsigned int num;
 		unsigned md_len;
@@ -213,8 +209,8 @@ void x86_sha512_update(struct sha512_ctx *ctx, size_t length,
 	if (length > 0) {
 		t2 = length / SHA512_DATA_SIZE;
 		sha512_block_data_order(&octx, data, t2);
-		
-		for (i=0;i<t2;i++)
+
+		for (i = 0; i < t2; i++)
 			MD_INCR(ctx);
 		data += length;
 	}
@@ -229,47 +225,46 @@ void x86_sha512_update(struct sha512_ctx *ctx, size_t length,
 	}
 }
 
-static int _ctx_init(gnutls_digest_algorithm_t algo,
-		     struct x86_hash_ctx *ctx)
+static int _ctx_init(gnutls_digest_algorithm_t algo, struct x86_hash_ctx *ctx)
 {
 	switch (algo) {
 	case GNUTLS_DIG_SHA1:
 		sha1_init(&ctx->ctx.sha1);
-		ctx->update = (update_func) x86_sha1_update;
-		ctx->digest = (digest_func) sha1_digest;
-		ctx->init = (init_func) sha1_init;
+		ctx->update = (update_func)x86_sha1_update;
+		ctx->digest = (digest_func)sha1_digest;
+		ctx->init = (init_func)sha1_init;
 		ctx->ctx_ptr = &ctx->ctx.sha1;
 		ctx->length = SHA1_DIGEST_SIZE;
 		break;
 	case GNUTLS_DIG_SHA224:
 		sha224_init(&ctx->ctx.sha224);
-		ctx->update = (update_func) x86_sha256_update;
-		ctx->digest = (digest_func) sha224_digest;
-		ctx->init = (init_func) sha224_init;
+		ctx->update = (update_func)x86_sha256_update;
+		ctx->digest = (digest_func)sha224_digest;
+		ctx->init = (init_func)sha224_init;
 		ctx->ctx_ptr = &ctx->ctx.sha224;
 		ctx->length = SHA224_DIGEST_SIZE;
 		break;
 	case GNUTLS_DIG_SHA256:
 		sha256_init(&ctx->ctx.sha256);
-		ctx->update = (update_func) x86_sha256_update;
-		ctx->digest = (digest_func) sha256_digest;
-		ctx->init = (init_func) sha256_init;
+		ctx->update = (update_func)x86_sha256_update;
+		ctx->digest = (digest_func)sha256_digest;
+		ctx->init = (init_func)sha256_init;
 		ctx->ctx_ptr = &ctx->ctx.sha256;
 		ctx->length = SHA256_DIGEST_SIZE;
 		break;
 	case GNUTLS_DIG_SHA384:
 		sha384_init(&ctx->ctx.sha384);
-		ctx->update = (update_func) x86_sha512_update;
-		ctx->digest = (digest_func) sha512_digest;
-		ctx->init = (init_func) sha384_init;
+		ctx->update = (update_func)x86_sha512_update;
+		ctx->digest = (digest_func)sha384_digest;
+		ctx->init = (init_func)sha384_init;
 		ctx->ctx_ptr = &ctx->ctx.sha384;
 		ctx->length = SHA384_DIGEST_SIZE;
 		break;
 	case GNUTLS_DIG_SHA512:
 		sha512_init(&ctx->ctx.sha512);
-		ctx->update = (update_func) x86_sha512_update;
-		ctx->digest = (digest_func) sha512_digest;
-		ctx->init = (init_func) sha512_init;
+		ctx->update = (update_func)x86_sha512_update;
+		ctx->digest = (digest_func)sha512_digest;
+		ctx->init = (init_func)sha512_init;
 		ctx->ctx_ptr = &ctx->ctx.sha512;
 		ctx->length = SHA512_DIGEST_SIZE;
 		break;
@@ -281,7 +276,6 @@ static int _ctx_init(gnutls_digest_algorithm_t algo,
 	return 0;
 }
 
-
 static int wrap_x86_hash_init(gnutls_digest_algorithm_t algo, void **_ctx)
 {
 	struct x86_hash_ctx *ctx;
@@ -296,6 +290,7 @@ static int wrap_x86_hash_init(gnutls_digest_algorithm_t algo, void **_ctx)
 	ctx->algo = algo;
 
 	if ((ret = _ctx_init(algo, ctx)) < 0) {
+		gnutls_free(ctx);
 		gnutls_assert();
 		return ret;
 	}
@@ -305,11 +300,10 @@ static int wrap_x86_hash_init(gnutls_digest_algorithm_t algo, void **_ctx)
 	return 0;
 }
 
-static void *
-wrap_x86_hash_copy(const void *_ctx)
+static void *wrap_x86_hash_copy(const void *_ctx)
 {
 	struct x86_hash_ctx *new_ctx;
-	const struct x86_hash_ctx *ctx=_ctx;
+	const struct x86_hash_ctx *ctx = _ctx;
 	ptrdiff_t off = (uint8_t *)ctx->ctx_ptr - (uint8_t *)(&ctx->ctx);
 
 	new_ctx = gnutls_malloc(sizeof(struct x86_hash_ctx));
@@ -324,12 +318,16 @@ wrap_x86_hash_copy(const void *_ctx)
 	return new_ctx;
 }
 
-static int
-wrap_x86_hash_output(void *src_ctx, void *digest, size_t digestsize)
+static int wrap_x86_hash_output(void *src_ctx, void *digest, size_t digestsize)
 {
 	struct x86_hash_ctx *ctx;
 	ctx = src_ctx;
 
+	if (digest == NULL) {
+		ctx->init(ctx->ctx_ptr);
+		return 0;
+	}
+
 	if (digestsize < ctx->length)
 		return gnutls_assert_val(GNUTLS_E_SHORT_MEMORY_BUFFER);
 
@@ -338,9 +336,8 @@ wrap_x86_hash_output(void *src_ctx, void *digest, size_t digestsize)
 	return 0;
 }
 
-static int wrap_x86_hash_fast(gnutls_digest_algorithm_t algo,
-				 const void *text, size_t text_size,
-				 void *digest)
+static int wrap_x86_hash_fast(gnutls_digest_algorithm_t algo, const void *text,
+			      size_t text_size, void *digest)
 {
 	struct x86_hash_ctx ctx;
 	int ret;
@@ -356,16 +353,16 @@ static int wrap_x86_hash_fast(gnutls_digest_algorithm_t algo,
 }
 
 const struct nettle_hash x86_sha1 =
-NN_HASH(sha1, x86_sha1_update, sha1_digest, SHA1);
+	NN_HASH(sha1, x86_sha1_update, sha1_digest, SHA1);
 const struct nettle_hash x86_sha224 =
-NN_HASH(sha224, x86_sha256_update, sha224_digest, SHA224);
+	NN_HASH(sha224, x86_sha256_update, sha224_digest, SHA224);
 const struct nettle_hash x86_sha256 =
-NN_HASH(sha256, x86_sha256_update, sha256_digest, SHA256);
+	NN_HASH(sha256, x86_sha256_update, sha256_digest, SHA256);
 
 const struct nettle_hash x86_sha384 =
-NN_HASH(sha384, x86_sha512_update, sha384_digest, SHA384);
+	NN_HASH(sha384, x86_sha512_update, sha384_digest, SHA384);
 const struct nettle_hash x86_sha512 =
-NN_HASH(sha512, x86_sha512_update, sha512_digest, SHA512);
+	NN_HASH(sha512, x86_sha512_update, sha512_digest, SHA512);
 
 const gnutls_crypto_digest_st _gnutls_sha_x86_ssse3 = {
 	.init = wrap_x86_hash_init,
