@@ -21,10 +21,10 @@
  */
 
 #include "gnutls_int.h"
-#include <algorithms.h>
+#include "algorithms.h"
 #include "errors.h"
-#include <x509/common.h>
-#include <pk.h>
+#include "x509/common.h"
+#include "pk.h"
 #include "c-strcase.h"
 
 /* Supported ECC curves
