@@ -21,47 +21,56 @@
  */
 
 #include "gnutls_int.h"
-#include <algorithms.h>
+#include "algorithms.h"
 #include "errors.h"
-#include <x509/common.h>
+#include "x509/common.h"
 
 typedef struct {
 	const char *name;
 	gnutls_sec_param_t sec_param;
-	unsigned int bits;	/* security level */
-	unsigned int pk_bits;	/* DH, RSA, SRP */
-	unsigned int dsa_bits;	/* bits for DSA. Handled differently since
+	unsigned int bits; /* security level */
+	unsigned int pk_bits; /* DH, RSA, SRP */
+	unsigned int dsa_bits; /* bits for DSA. Handled differently since
 				 * choice of key size in DSA is political.
 				 */
-	unsigned int subgroup_bits;	/* subgroup bits */
-	unsigned int ecc_bits;	/* bits for ECC keys */
+	unsigned int subgroup_bits; /* subgroup bits */
+	unsigned int ecc_bits; /* bits for ECC keys */
+	unsigned int ml_dsa_bits;
 } gnutls_sec_params_entry;
 
 static const gnutls_sec_params_entry sec_params[] = {
-	{"Insecure", GNUTLS_SEC_PARAM_INSECURE, 0, 0, 0, 0, 0},
-	{"Export", GNUTLS_SEC_PARAM_EXPORT, 42, 512, 0, 84, 0},
-	{"Very weak", GNUTLS_SEC_PARAM_VERY_WEAK, 64, 767, 0, 128, 0},
-	{"Weak", GNUTLS_SEC_PARAM_WEAK, 72, 1008, 1008, 160, 160},
+	{ "Insecure", GNUTLS_SEC_PARAM_INSECURE, 0, 0, 0, 0, 0, 0 },
+	{ "Export", GNUTLS_SEC_PARAM_EXPORT, 42, 512, 0, 84, 0, 0 },
+	{ "Very weak", GNUTLS_SEC_PARAM_VERY_WEAK, 64, 767, 0, 128, 0, 0 },
+	{ "Weak", GNUTLS_SEC_PARAM_WEAK, 72, 1008, 1008, 160, 160, 0 },
 #ifdef ENABLE_FIPS140
-	{"Low", GNUTLS_SEC_PARAM_LOW, 80, 1024, 1024, 160, 160},
-	{"Legacy", GNUTLS_SEC_PARAM_LEGACY, 96, 1024, 1024, 192, 192},
-	{"Medium", GNUTLS_SEC_PARAM_MEDIUM, 112, 2048, 2048, 224, 224},
-	{"High", GNUTLS_SEC_PARAM_HIGH, 128, 3072, 3072, 256, 256},
+	{ "Low", GNUTLS_SEC_PARAM_LOW, 80, 1024, 1024, 160, 160, 0 },
+	{
+		"Legacy",
+		GNUTLS_SEC_PARAM_LEGACY,
+		96,
+		1024,
+		1024,
+		192,
+		192,
+		0,
+	},
+	{ "Medium", GNUTLS_SEC_PARAM_MEDIUM, 112, 2048, 2048, 224, 224, 0 },
+	{ "High", GNUTLS_SEC_PARAM_HIGH, 128, 3072, 3072, 256, 256, 0 },
 #else
-	{"Low", GNUTLS_SEC_PARAM_LOW, 80, 1024, 1024, 160, 160}, /* ENISA-LEGACY */
-	{"Legacy", GNUTLS_SEC_PARAM_LEGACY, 96, 1776, 2048, 192, 192},
-	{"Medium", GNUTLS_SEC_PARAM_MEDIUM, 112, 2048, 2048, 256, 224},
-	{"High", GNUTLS_SEC_PARAM_HIGH, 128, 3072, 3072, 256, 256},
+	{ "Low", GNUTLS_SEC_PARAM_LOW, 80, 1024, 1024, 160, 160,
+	  0 }, /* ENISA-LEGACY */
+	{ "Legacy", GNUTLS_SEC_PARAM_LEGACY, 96, 1776, 2048, 192, 192, 0 },
+	{ "Medium", GNUTLS_SEC_PARAM_MEDIUM, 112, 2048, 2048, 256, 224, 0 },
+	{ "High", GNUTLS_SEC_PARAM_HIGH, 128, 3072, 3072, 256, 256, 0 },
 #endif
-	{"Ultra", GNUTLS_SEC_PARAM_ULTRA, 192, 8192, 8192, 384, 384},
-	{"Future", GNUTLS_SEC_PARAM_FUTURE, 256, 15360, 15360, 512, 512},
-	{NULL, 0, 0, 0, 0, 0}
+	{ "Ultra", GNUTLS_SEC_PARAM_ULTRA, 192, 8192, 8192, 384, 384,
+	  MLDSA65_PUBKEY_SIZE },
+	{ "Future", GNUTLS_SEC_PARAM_FUTURE, 256, 15360, 15360, 512, 512,
+	  MLDSA87_PUBKEY_SIZE },
+	{ NULL, 0, 0, 0, 0, 0, 0, 0 }
 };
 
-#define GNUTLS_SEC_PARAM_LOOP(b) \
-	{ const gnutls_sec_params_entry *p; \
-		for(p = sec_params; p->name != NULL; p++) { b ; } }
-
 /**
  * gnutls_sec_param_to_pk_bits:
  * @algo: is a public key algorithm
@@ -77,24 +86,27 @@ static const gnutls_sec_params_entry sec_params[] = {
  *
  * Since: 2.12.0
  **/
-unsigned int
-gnutls_sec_param_to_pk_bits(gnutls_pk_algorithm_t algo,
-			    gnutls_sec_param_t param)
+unsigned int gnutls_sec_param_to_pk_bits(gnutls_pk_algorithm_t algo,
+					 gnutls_sec_param_t param)
 {
 	unsigned int ret = 0;
+	const gnutls_sec_params_entry *p;
 
 	/* handle DSA differently */
-	GNUTLS_SEC_PARAM_LOOP(
-	if (p->sec_param == param) {
-		if (algo == GNUTLS_PK_DSA)
-			ret = p->dsa_bits;
-		else if (IS_EC(algo)||IS_GOSTEC(algo))
-			ret = p->ecc_bits;
-		else
-			ret = p->pk_bits;
-		break;
+	for (p = sec_params; p->name; p++) {
+		if (p->sec_param == param) {
+			if (algo == GNUTLS_PK_DSA)
+				ret = p->dsa_bits;
+			else if (IS_EC(algo) || IS_GOSTEC(algo))
+				ret = p->ecc_bits;
+			else if (IS_ML_DSA(algo))
+				ret = p->ml_dsa_bits;
+			else
+				ret = p->pk_bits;
+			break;
+		}
 	}
-	);
+
 	return ret;
 }
 
@@ -110,17 +122,19 @@ gnutls_sec_param_to_pk_bits(gnutls_pk_algorithm_t algo,
  *
  * Since: 3.3.0
  **/
-unsigned int
-gnutls_sec_param_to_symmetric_bits(gnutls_sec_param_t param)
+unsigned int gnutls_sec_param_to_symmetric_bits(gnutls_sec_param_t param)
 {
 	unsigned int ret = 0;
+	const gnutls_sec_params_entry *p;
 
 	/* handle DSA differently */
-	GNUTLS_SEC_PARAM_LOOP(
-	if (p->sec_param == param) {
-		ret = p->bits; break;
+	for (p = sec_params; p->name; p++) {
+		if (p->sec_param == param) {
+			ret = p->bits;
+			break;
+		}
 	}
-	);
+
 	return ret;
 }
 
@@ -130,12 +144,14 @@ gnutls_sec_param_to_symmetric_bits(gnutls_sec_param_t param)
 unsigned int _gnutls_pk_bits_to_subgroup_bits(unsigned int pk_bits)
 {
 	unsigned int ret = 0;
+	const gnutls_sec_params_entry *p;
 
-	GNUTLS_SEC_PARAM_LOOP(
+	for (p = sec_params; p->name; p++) {
 		ret = p->subgroup_bits;
 		if (p->pk_bits >= pk_bits)
 			break;
-	);
+	}
+
 	return ret;
 }
 
@@ -144,7 +160,9 @@ unsigned int _gnutls_pk_bits_to_subgroup_bits(unsigned int pk_bits)
  */
 gnutls_digest_algorithm_t _gnutls_pk_bits_to_sha_hash(unsigned int pk_bits)
 {
-	GNUTLS_SEC_PARAM_LOOP(
+	const gnutls_sec_params_entry *p;
+
+	for (p = sec_params; p->name; p++) {
 		if (p->pk_bits >= pk_bits) {
 			if (p->bits <= 128)
 				return GNUTLS_DIG_SHA256;
@@ -153,7 +171,8 @@ gnutls_digest_algorithm_t _gnutls_pk_bits_to_sha_hash(unsigned int pk_bits)
 			else
 				return GNUTLS_DIG_SHA512;
 		}
-	);
+	}
+
 	return GNUTLS_DIG_SHA256;
 }
 
@@ -171,13 +190,14 @@ gnutls_digest_algorithm_t _gnutls_pk_bits_to_sha_hash(unsigned int pk_bits)
 const char *gnutls_sec_param_get_name(gnutls_sec_param_t param)
 {
 	const char *ret = "Unknown";
+	const gnutls_sec_params_entry *p;
 
-	GNUTLS_SEC_PARAM_LOOP(
+	for (p = sec_params; p->name; p++) {
 		if (p->sec_param == param) {
 			ret = p->name;
 			break;
 		}
-	);
+	}
 
 	return ret;
 }
@@ -195,28 +215,33 @@ const char *gnutls_sec_param_get_name(gnutls_sec_param_t param)
  *
  * Since: 2.12.0
  **/
-gnutls_sec_param_t
-gnutls_pk_bits_to_sec_param(gnutls_pk_algorithm_t algo, unsigned int bits)
+gnutls_sec_param_t gnutls_pk_bits_to_sec_param(gnutls_pk_algorithm_t algo,
+					       unsigned int bits)
 {
 	gnutls_sec_param_t ret = GNUTLS_SEC_PARAM_INSECURE;
+	const gnutls_sec_params_entry *p;
 
 	if (bits == 0)
 		return GNUTLS_SEC_PARAM_UNKNOWN;
 
-	if (IS_EC(algo)||IS_GOSTEC(algo)) {
-		GNUTLS_SEC_PARAM_LOOP(
-			if (p->ecc_bits > bits) {
+	if (IS_EC(algo) || IS_GOSTEC(algo)) {
+		for (p = sec_params; p->name; p++) {
+			if (p->ecc_bits > bits)
 				break;
-			}
 			ret = p->sec_param;
-		);
+		}
+	} else if (IS_ML_DSA(algo)) {
+		for (p = sec_params; p->name; p++) {
+			if (p->ml_dsa_bits > bits)
+				break;
+			ret = p->sec_param;
+		}
 	} else {
-		GNUTLS_SEC_PARAM_LOOP(
-			if (p->pk_bits > bits) {
-			      break;
-			}
+		for (p = sec_params; p->name; p++) {
+			if (p->pk_bits > bits)
+				break;
 			ret = p->sec_param;
-		);
+		}
 	}
 
 	return ret;
