@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2014 Free Software Foundation, Inc.
+ * Copyright (C) 2002-2025 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -14,11 +14,11 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA
+ * License along with this library; if not, see
+ * <https://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
 
 /*****************************************************/
 /* File: structure.c                                 */
@@ -31,6 +31,9 @@
 #include <structure.h>
 #include "parser_aux.h"
 #include <gstr.h>
+#include "c-ctype.h"
+#include "element.h"
+#include <limits.h>
 
 
 extern char _asn1_identifierMissing[];
@@ -78,8 +81,8 @@ _asn1_find_left (asn1_node_const node)
 
 
 int
-_asn1_create_static_structure (asn1_node_const pointer, char *output_file_name,
-			       char *vector_name)
+_asn1_create_static_structure (asn1_node_const pointer,
+			       char *output_file_name, char *vector_name)
 {
   FILE *file;
   asn1_node_const p;
@@ -174,7 +177,7 @@ _asn1_create_static_structure (asn1_node_const pointer, char *output_file_name,
  *   %ASN1_ARRAY_ERROR if the array pointed by @array is wrong.
  **/
 int
-asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
+asn1_array2tree (const asn1_static_node *array, asn1_node *definitions,
 		 char *errorDescription)
 {
   asn1_node p, p_last = NULL;
@@ -208,15 +211,15 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
       if (move == DOWN)
 	{
 	  if (p_last && p_last->down)
-	      _asn1_delete_structure (e_list, &p_last->down, 0);
+	    _asn1_delete_structure (e_list, &p_last->down, 0);
 	  _asn1_set_down (p_last, p);
 	}
       else if (move == RIGHT)
-        {
+	{
 	  if (p_last && p_last->right)
-	      _asn1_delete_structure (e_list, &p_last->right, 0);
+	    _asn1_delete_structure (e_list, &p_last->right, 0);
 	  _asn1_set_right (p_last, p);
-        }
+	}
 
       p_last = p;
 
@@ -291,7 +294,7 @@ asn1_array2tree (const asn1_static_node * array, asn1_node * definitions,
  *   *@structure was NULL.
  **/
 int
-asn1_delete_structure (asn1_node * structure)
+asn1_delete_structure (asn1_node *structure)
 {
   return _asn1_delete_structure (NULL, structure, 0);
 }
@@ -299,7 +302,7 @@ asn1_delete_structure (asn1_node * structure)
 /**
  * asn1_delete_structure2:
  * @structure: pointer to the structure that you want to delete.
- * @flags: additional flags (see %ASN1_DELETE_FLAG)
+ * @flags: additional flags (see %ASN1_DELETE_FLAG_ZEROIZE)
  *
  * Deletes the structure *@structure.  At the end, *@structure is set
  * to NULL.
@@ -308,13 +311,14 @@ asn1_delete_structure (asn1_node * structure)
  *   *@structure was NULL.
  **/
 int
-asn1_delete_structure2 (asn1_node * structure, unsigned int flags)
+asn1_delete_structure2 (asn1_node *structure, unsigned int flags)
 {
   return _asn1_delete_structure (NULL, structure, flags);
 }
 
 int
-_asn1_delete_structure (list_type *e_list, asn1_node * structure, unsigned int flags)
+_asn1_delete_structure (list_type *e_list, asn1_node *structure,
+			unsigned int flags)
 {
   asn1_node p, p2, p3;
 
@@ -390,6 +394,15 @@ asn1_delete_element (asn1_node structure, const char *element_name)
   if (source_node == NULL)
     return ASN1_ELEMENT_NOT_FOUND;
 
+  if (source_node->parent
+      && source_node->name[0] == '?' && c_isdigit (source_node->name[1]))
+    {
+      long position = strtol (source_node->name + 1, NULL, 10);
+      if (position > 0 && position < LONG_MAX)
+	_asn1_node_array_set (&source_node->parent->numbered_children,
+			      position - 1, NULL);
+    }
+
   p2 = source_node->right;
   p3 = _asn1_find_left (source_node);
   if (!p3)
@@ -418,6 +431,8 @@ _asn1_copy_structure3 (asn1_node_const source_node)
     return NULL;
 
   dest_node = _asn1_add_single_node (source_node->type);
+  if (dest_node == NULL)
+    return dest_node;
 
   p_s = source_node;
   p_d = dest_node;
@@ -575,7 +590,7 @@ _asn1_type_choice_config (asn1_node node)
 
 
 static int
-_asn1_expand_identifier (asn1_node * node, asn1_node_const root)
+_asn1_expand_identifier (asn1_node *node, asn1_node_const root)
 {
   asn1_node p, p2, p3;
   char name2[ASN1_MAX_NAME_SIZE + 2];
@@ -698,7 +713,7 @@ _asn1_expand_identifier (asn1_node * node, asn1_node_const root)
  **/
 int
 asn1_create_element (asn1_node_const definitions, const char *source_name,
-		     asn1_node * element)
+		     asn1_node *element)
 {
   asn1_node dest_node;
   int res;
@@ -732,7 +747,7 @@ asn1_create_element (asn1_node_const definitions, const char *source_name,
  * from the @name element inside the structure @structure.
  **/
 void
-asn1_print_structure (FILE * out, asn1_node_const structure, const char *name,
+asn1_print_structure (FILE *out, asn1_node_const structure, const char *name,
 		      int mode)
 {
   asn1_node_const p, root;
@@ -890,7 +905,8 @@ asn1_print_structure (FILE * out, asn1_node_const structure, const char *name,
 		      fprintf (out, "  value(%i):",
 			       (len - 1) * 8 - (p->value[len2]));
 		      for (k = 1; k < len; k++)
-			fprintf (out, "%02x", (unsigned) (p->value)[k + len2]);
+			fprintf (out, "%02x",
+				 (unsigned) (p->value)[k + len2]);
 		    }
 		}
 	      break;
@@ -1112,7 +1128,8 @@ asn1_number_of_elements (asn1_node_const element, const char *name, int *num)
  *   the OID.
  **/
 const char *
-asn1_find_structure_from_oid (asn1_node_const definitions, const char *oidValue)
+asn1_find_structure_from_oid (asn1_node_const definitions,
+			      const char *oidValue)
 {
   char name[2 * ASN1_MAX_NAME_SIZE + 2];
   char value[ASN1_MAX_NAME_SIZE];
@@ -1133,7 +1150,7 @@ asn1_find_structure_from_oid (asn1_node_const definitions, const char *oidValue)
       if ((type_field (p->type) == ASN1_ETYPE_OBJECT_ID) &&
 	  (p->type & CONST_ASSIGN))
 	{
-          snprintf(name, sizeof(name), "%s.%s", definitionsName, p->name);
+	  snprintf (name, sizeof (name), "%s.%s", definitionsName, p->name);
 
 	  len = ASN1_MAX_NAME_SIZE;
 	  result = asn1_read_value (definitions, name, value, &len);
@@ -1216,5 +1233,5 @@ asn1_copy_node (asn1_node dst, const char *dst_name,
 asn1_node
 asn1_dup_node (asn1_node_const src, const char *src_name)
 {
-  return _asn1_copy_structure2(src, src_name);
+  return _asn1_copy_structure2 (src, src_name);
 }
