@@ -24,8 +24,10 @@
 #define GNUTLS_LIB_TLS13_CERTIFICATE_REQUEST_H
 
 int _gnutls13_recv_certificate_request(gnutls_session_t session);
-int _gnutls13_recv_certificate_request_int(gnutls_session_t session, gnutls_buffer_st *buf);
+int _gnutls13_recv_certificate_request_int(gnutls_session_t session,
+					   gnutls_buffer_st *buf);
 
-int _gnutls13_send_certificate_request(gnutls_session_t session, unsigned again);
+int _gnutls13_send_certificate_request(gnutls_session_t session,
+				       unsigned again);
 
 #endif /* GNUTLS_LIB_TLS13_CERTIFICATE_REQUEST_H */
