@@ -25,17 +25,17 @@
  */
 
 #include "gnutls_int.h"
-#include <global.h>
+#include "global.h"
 #include "errors.h"
 #include <libtasn1.h>
-#include <pk.h>
+#include "pk.h"
 #include "common.h"
 #include "verify-high.h"
 #include "x509.h"
 #include "ocsp.h"
 
 #include <gnutls/ocsp.h>
-#include <auth/cert.h>
+#include "auth/cert.h"
 
 #include <assert.h>
 #include "intprops.h"
@@ -2466,6 +2466,7 @@ int gnutls_ocsp_resp_list_import2(gnutls_ocsp_resp_t **ocsps,
 	goto cleanup;
 
 fail:
+	assert((*size == 0 && *ocsps == NULL) || (*size > 0 && *ocsps != NULL));
 	for (i = 0; i < *size; i++) {
 		gnutls_ocsp_resp_deinit((*ocsps)[i]);
 	}
