@@ -30,6 +30,7 @@ struct gnutls_cli_options
     bool verify_hostname;
     bool starttls;
     bool starttls_proto;
+    bool starttls_name;
     bool udp;
     bool mtu;
     bool crlf;
@@ -96,6 +97,7 @@ struct gnutls_cli_options
     const char *sni_hostname;
     const char *verify_hostname;
     const char *starttls_proto;
+    const char *starttls_name;
     const char *mtu;
     const char *save_cert;
     const char *save_ocsp;
@@ -161,6 +163,7 @@ struct gnutls_cli_options
     bool verify_hostname;
     bool starttls;
     bool starttls_proto;
+    bool starttls_name;
     bool udp;
     bool mtu;
     bool crlf;
@@ -242,6 +245,7 @@ struct gnutls_cli_options
 #define HAVE_OPT_VERIFY_HOSTNAME gnutls_cli_options.present.verify_hostname
 #define HAVE_OPT_STARTTLS gnutls_cli_options.present.starttls
 #define HAVE_OPT_STARTTLS_PROTO gnutls_cli_options.present.starttls_proto
+#define HAVE_OPT_STARTTLS_NAME gnutls_cli_options.present.starttls_name
 #define HAVE_OPT_UDP gnutls_cli_options.present.udp
 #define HAVE_OPT_MTU gnutls_cli_options.present.mtu
 #define HAVE_OPT_CRLF gnutls_cli_options.present.crlf
@@ -314,6 +318,7 @@ struct gnutls_cli_options
 #define OPT_ARG_VERIFY_HOSTNAME gnutls_cli_options.arg.verify_hostname
 #define OPT_ARG_STARTTLS gnutls_cli_options.arg.starttls
 #define OPT_ARG_STARTTLS_PROTO gnutls_cli_options.arg.starttls_proto
+#define OPT_ARG_STARTTLS_NAME gnutls_cli_options.arg.starttls_name
 #define OPT_ARG_UDP gnutls_cli_options.arg.udp
 #define OPT_ARG_MTU gnutls_cli_options.arg.mtu
 #define OPT_ARG_CRLF gnutls_cli_options.arg.crlf
@@ -392,6 +397,7 @@ struct gnutls_cli_options
 #define ENABLED_OPT_VERIFY_HOSTNAME gnutls_cli_options.enabled.verify_hostname
 #define ENABLED_OPT_STARTTLS gnutls_cli_options.enabled.starttls
 #define ENABLED_OPT_STARTTLS_PROTO gnutls_cli_options.enabled.starttls_proto
+#define ENABLED_OPT_STARTTLS_NAME gnutls_cli_options.enabled.starttls_name
 #define ENABLED_OPT_UDP gnutls_cli_options.enabled.udp
 #define ENABLED_OPT_MTU gnutls_cli_options.enabled.mtu
 #define ENABLED_OPT_CRLF gnutls_cli_options.enabled.crlf
