@@ -19,8 +19,8 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>
  */
 
-#ifndef HEX_H
-#define HEX_H
+#ifndef GNUTLS_TESTS_HEX_H
+#define GNUTLS_TESTS_HEX_H
 
 #include <stdio.h>
 #include <string.h>
@@ -31,7 +31,7 @@ inline static gnutls_datum_t SHEX(const char *hex)
 	gnutls_datum_t input, output;
 	int ret;
 
-	input.data = (void*)hex;
+	input.data = (void *)hex;
 	input.size = strlen(hex);
 
 	ret = gnutls_hex_decode2(&input, &output);
@@ -42,9 +42,9 @@ inline static gnutls_datum_t SHEX(const char *hex)
 inline static gnutls_datum_t SDATA(const char *txt)
 {
 	gnutls_datum_t output;
-	output.data = (void*)gnutls_strdup(txt);
+	output.data = (void *)gnutls_strdup(txt);
 	output.size = strlen(txt);
 	return output;
 }
 
-#endif
+#endif /* GNUTLS_TESTS_HEX_H */
